@@ -33,7 +33,7 @@ def sp(text):
     time.sleep(0.05)
     sys.stdout.flush()
 def clear():
-  os.system("clear")
+  print("\033c", end = "")
 
 class color():
   def spc(text,color):
